@@ -2,6 +2,12 @@ package Net::Whois::Object::Response;
 
 use base qw/Net::Whois::Object/;
 
+__PACKAGE__->attributes( 'mandatory', ['response'] );
+__PACKAGE__->attributes( 'optional', ['comment'] );
+__PACKAGE__->attributes( 'single',    ['response'] );
+__PACKAGE__->attributes( 'multiple',  ['comment'] );
+
+
 =head1 NAME
 
 Net::Whois::Object::Response - an object representation of the RPSL Response block
@@ -32,11 +38,6 @@ sub new {
     my $self = bless {}, $class;
     $self->_init(@options);
 
-    $self->attributes( 'mandatory', ['response'] );
-    $self->attributes( 'optional', ['comment'] );
-    $self->attributes( 'single',    ['response'] );
-    $self->attributes( 'multiple',  ['comment'] );
-
     return $self;
 }
 
@@ -45,14 +46,6 @@ sub new {
 Accessor to the response attribute.
 Accepts an optional response, always return the current response.
 
-=cut
-
-sub response {
-    my ( $self, $response ) = @_;
-
-    return $self->_single_attribute_setget( 'response', $response );
-}
-
 =head2 B<comment( [$comment] )>
 
 Accessor to the comment attribute.
@@ -60,10 +53,4 @@ Accepts an optional comment, always return the current comment.
 
 =cut
 
-sub comment {
-    my ( $self, $comment ) = @_;
-
-    return $self->_multiple_attribute_setget( 'comment', $comment );
-}
-
 1;
